<?php

/*

Plugin Name: Future Gallery
Plugin URI:
Version: 1.13
Description: Display futurist gallery !
Author: Manu225
Author URI: 
Network: false
Text Domain: future-gallery
Domain Path: 

*/

register_activation_hook( __FILE__, 'future_gallery_install' );
register_uninstall_hook(__FILE__, 'future_gallery_desinstall');

function future_gallery_install()
{
	global $wpdb;

	$future_gallery_table = $wpdb->prefix . "future_gallery";
	$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

	$sql = "
        CREATE TABLE `".$future_gallery_table."` (
          id int(11) NOT NULL AUTO_INCREMENT,          
          name varchar(50) NOT NULL,
          height int(2) NOT NULL,
          width_thumbnails int(2) NOT NULL,
          title_size int(3) NOT NULL,
          PRIMARY KEY  (id)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
    ";

    dbDelta($sql);

    $sql = "
        CREATE TABLE `".$future_gallery_contents_table."` (
          id int(11) NOT NULL AUTO_INCREMENT,          
          title varchar(500) NOT NULL,
          text text NOT NULL,
          image varchar(500) NOT NULL,
          link varchar(500) NOT NULL,
          blank int(1) NOT NULL,
          `order` int(11) NOT NULL,
          id_gallery int(11),
          PRIMARY KEY  (id)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
    ";
    
    dbDelta($sql);
}

function future_gallery_desinstall()
{
	global $wpdb;

	$future_gallery_table = $wpdb->prefix . "future_gallery";
	$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

	//suppression des tables
	$sql = "DROP TABLE ".$future_gallery_table.";";
	$wpdb->query($sql);

    $sql = "DROP TABLE ".$future_gallery_contents_table.";";   
	$wpdb->query($sql);
}

add_action( 'admin_menu', 'register_future_gallery_menu' );
function register_future_gallery_menu() {

	add_menu_page('Future Gallery', 'Future Gallery', 'edit_pages', 'future_gallery', 'future_gallery',   '', 31);
	add_submenu_page( 'future_gallery', 'Help', 'Help', 'edit_pages', 'future_gallery_help', 'future_gallery_help');

}

add_action('admin_print_styles', 'future_gallery_css' );
function future_gallery_css() {
    wp_enqueue_style( 'FutureGalleryStylesheet', plugins_url('css/admin.css', __FILE__) );
    wp_enqueue_style( 'wp-color-picker' );
}

// UPLOAD ENGINE
function future_gallery_scripts() {
    wp_enqueue_media();
    wp_enqueue_script( 'wp-color-picker' );
    wp_enqueue_script('jquery');
    wp_enqueue_script('jquery-ui-core');
    wp_enqueue_script('jquery-ui-sortable');
}
add_action( 'admin_enqueue_scripts', 'future_gallery_scripts' );

function future_gallery()
{
	global $wpdb, $EFFECTS, $POSITIONS_TN;

	$future_gallery_table = $wpdb->prefix . "future_gallery";
	$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

	if(is_numeric($_GET['id']))
	{
		//récupère la galerie à manager
		$gallery = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM ".$future_gallery_table." WHERE id=%d", $_GET['id'] ));
		$contents = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM ".$future_gallery_contents_table." WHERE id_gallery = %d ORDER BY `order` ASC", $_GET['id'], OBJECT) );
		include(plugin_dir_path( __FILE__ ) . 'views/gallery.php');
	}
	else
	{
		if(sizeof($_POST) > 0)
		{
			if(empty($_POST['name']))
				echo '<h2>You must enter a name for your future gallery !</h2>';
			else if(!is_numeric($_POST['id'])) //nouvelle future gallery
			{
				check_admin_referer( 'new_fg' );
				$query = $wpdb->prepare( "INSERT INTO ".$future_gallery_table." (`name`, `height`, `title_size`, `width_thumbnails`)
				VALUES (%s, %d, %d, %d)", sanitize_text_field(stripslashes_deep($_POST['name'])), $_POST['height'], $_POST['title_size'], $_POST['width_thumbnails']);
				$wpdb->query($query);
			}
			else //mise à jour d'une future gallery
			{
				check_admin_referer( 'update_fg_'.$_POST['id'] );
				$query = $wpdb->prepare( "UPDATE ".$future_gallery_table." SET `name` = %s, `height` = %d, `title_size` = %d, `width_thumbnails` = %d 
				WHERE id = %d",	sanitize_text_field(stripslashes_deep($_POST['name'])), $_POST['height'], $_POST['title_size'],
				$_POST['width_thumbnails'], $_POST['id'] );
				$wpdb->query($query);
			}
		}

		$query = "SELECT * FROM ".$future_gallery_table." ORDER BY name ASC";
		$galleries = $wpdb->get_results( $query );
		include(plugin_dir_path( __FILE__ ) . 'views/galleries.php');
	}
}

function future_gallery_help()
{
	include(plugin_dir_path( __FILE__ ) . 'views/help.php');
}

//Ajax : suppression d'une gallerie
add_action( 'wp_ajax_remove_fg', 'remove_fg' );

function remove_fg() {

	check_ajax_referer( 'remove_fg' );

	if (is_admin()) {

		global $wpdb;

		$future_gallery_table = $wpdb->prefix . "future_gallery";
		$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

		if(is_numeric($_POST['id']))
		{
			//supprime toutes les contenus
			$query = $wpdb->prepare( 
				"DELETE FROM ".$future_gallery_contents_table."
				 WHERE id=%d", $_POST['id']
			);
			$res = $wpdb->query( $query	);
			//supprime la gallerie
			$query = $wpdb->prepare( 
				"DELETE FROM ".$future_gallery_table."
				 WHERE id=%d", $_POST['id']
			);
			$res = $wpdb->query( $query	);
		}
		wp_die();
	}
}

//Ajax : ajout d'un contenu à la gallerie
add_action( 'wp_ajax_fg_add_content', 'fg_add_content' );

function fg_add_content() {

	check_admin_referer( 'new_content_fg' );

	if (is_admin()) {

		global $wpdb;

		$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

		if(is_numeric($_POST['id']) && !empty($_POST['title']) && !empty($_POST['image']))
		{
			$max_order = $wpdb->get_row( $wpdb->prepare( "SELECT MAX(`order`) as max_order FROM ".$future_gallery_contents_table." WHERE id_gallery = %d", $_POST['id'] ));
			if($max_order)
				$max_order = ($max_order->max_order+1);
			else
				$max_order = 1;
			$query = $wpdb->prepare( "INSERT INTO ".$future_gallery_contents_table." (`image`, `title`, `text`, `link`, `blank`, `order`, `id_gallery`)
				VALUES (%s, %s, %s, %s, %d, %d, %d)", sanitize_text_field(stripslashes_deep($_POST['image'])), sanitize_text_field(stripslashes_deep($_POST['title'])), stripslashes_deep($_POST['text']), sanitize_text_field(stripslashes_deep($_POST['link'])), ($_POST['blank'] == '1' ? 1 : 0), $max_order, $_POST['id'] );

			$res = $wpdb->query( $query	);
		}
		wp_die($wpdb->insert_id);
	}
}

//Ajax : update d'un contenu	
add_action( 'wp_ajax_fg_save_content', 'fg_save_content');
function fg_save_content() {

	check_admin_referer( 'update_content_fg' );

	if (is_admin()) {	
		if(is_numeric($_POST['id']) && !empty($_POST['title']) && !empty($_POST['image']))
		{
			global $wpdb;

			$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

			$query = $wpdb->prepare( "UPDATE ".$future_gallery_contents_table." SET `title` = %s, `image` = %s, `text` = %s, `link` = %s, `blank` = %d WHERE id = %d",
			sanitize_text_field(stripslashes_deep($_POST['title'])), sanitize_text_field(stripslashes_deep($_POST['image'])), stripslashes_deep($_POST['text']), sanitize_text_field(stripslashes_deep($_POST['link'])), ($_POST['blank'] == '1' ? 1 : 0), $_POST['id'] );
			$res = $wpdb->query( $query	);
		}
	}
}

//Ajax : suppression d'un contenu	
add_action( 'wp_ajax_fg_remove_content', 'fg_remove_content');
function fg_remove_content() {

	check_ajax_referer( 'fg_remove_content' );

	if (is_admin()) {	
		if(is_numeric($_POST['id']))
		{
			global $wpdb;

			$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

			//on récupère le order du menu a supprimer
			$query = "SELECT `order` FROM ".$future_gallery_contents_table." WHERE id = %d";
			$content = $wpdb->get_row( $wpdb->prepare( $query, $_POST['id'] ));
			if($content)
			{
				//on met à jour les orders des contenus suivants
				$wpdb->query( $wpdb->prepare( "UPDATE ".$future_gallery_contents_table." SET `order` = `order` - 1 WHERE `order` > %d", $content->order));

				//supprime le contenu
				$query = $wpdb->prepare( 
					"DELETE FROM ".$future_gallery_contents_table."
					 WHERE id=%d", $_POST['id']
				);
				$res = $wpdb->query( $query	);
			}
		}
	}

	wp_die();
}

//Ajax : changement de position d'une icone
add_action( 'wp_ajax_fg_order_content', 'fg_order_content' );
function fg_order_content() {

	check_ajax_referer( 'fg_order_content' );

	if (is_admin()) {
		global $wpdb;

		$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

		if(is_numeric($_POST['id']) && is_numeric($_POST['order']))
		{
			$gallery = $wpdb->get_row( $wpdb->prepare( "SELECT id_gallery, `order` FROM ".$future_gallery_contents_table." WHERE id = %d", $_POST['id'] ));
			if($_POST['order'] > $gallery->order)
				$wpdb->query( $wpdb->prepare( "UPDATE ".$future_gallery_contents_table." SET `order` = `order` - 1 WHERE id_gallery = %d AND `order` <= %d AND `order` > %d", $gallery->id_gallery, $_POST['order'], $gallery->order ));
			else
				$wpdb->query( $wpdb->prepare( "UPDATE ".$future_gallery_contents_table." SET `order` = `order` + 1 WHERE id_gallery = %d AND `order` >= %d AND `order` < %d", $gallery->id_gallery, $_POST['order'], $gallery->order ));
			$wpdb->query( $wpdb->prepare( "UPDATE ".$future_gallery_contents_table." SET `order` = %d WHERE id = %d", $_POST['order'], $_POST['id'] ));
			
		}
		wp_die(); // this is required to terminate immediately and return a proper response
	}
}

add_shortcode('future-gallery', 'display_future_gallery');
function display_future_gallery($atts)
{
	if(is_numeric($atts['id']))
	{
		global $wpdb;

		$future_gallery_table = $wpdb->prefix . "future_gallery";
		$future_gallery_contents_table = $wpdb->prefix . "future_gallery_contents";

		$query = $wpdb->prepare( "SELECT * FROM ".$future_gallery_table." WHERE id = %d", $atts['id'] );
		$gallery = $wpdb->get_row( $query );

		if($gallery)
		{
			$query = $wpdb->prepare( "SELECT * FROM ".$future_gallery_contents_table." WHERE id_gallery = %d ORDER BY `order` ASC", $atts['id'] );
			$contents = $wpdb->get_results( $query );

			wp_enqueue_script( 'jquery');
			wp_enqueue_script( 'FutureGalleryFrontJS', plugins_url( 'js/front.js', __FILE__ ));
			wp_enqueue_style( 'FutureGalleryFrontStylesheet', plugins_url('css/front.css', __FILE__) );

			ob_start();
			include( plugin_dir_path( __FILE__ ) . 'views/future_gallery.tpl.php' );
			return ob_get_clean();
		}
		else
			return 'Future Gallery ID '.$atts['id'].' not found!';
	}
	else
		return 'Missing ID of Future Gallery to display!';
}

if( !function_exists('hex2rgb'))
{
	function hex2rbg($hex) {

     $hex = str_replace("#", "", $hex);



     if(strlen($hex) == 3) {

        $r = hexdec(substr($hex,0,1).substr($hex,0,1));

        $g = hexdec(substr($hex,1,1).substr($hex,1,1));

        $b = hexdec(substr($hex,2,1).substr($hex,2,1));

     } else {

        $r = hexdec(substr($hex,0,2));

        $g = hexdec(substr($hex,2,2));

        $b = hexdec(substr($hex,4,2));

     }

     $rgb = array($r, $g, $b);

     //return implode(",", $rgb); // returns the rgb values separated by commas

     return $rgb; // returns an array with the rgb values

   }
}